==> kubernetes-model-autoscaling-5.11.1-sources.jar: io/fabric8/kubernetes/api/model/autoscaling/v2beta2/ExternalMetricSourceFluentImpl.java <==
package io.fabric8.kubernetes.api.model.autoscaling.v2beta2;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class ExternalMetricSourceFluentImpl<A extends io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ExternalMetricSourceFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ExternalMetricSourceFluent<A>{
  public ExternalMetricSourceFluentImpl() {
  }
  public ExternalMetricSourceFluentImpl(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ExternalMetricSource instance) {
    this.withMetric(instance.getMetric()); 
    this.withTarget(instance.getTarget()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricIdentifierBuilder metric;
  private io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricTargetBuilder target;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildMetric instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricIdentifier getMetric() {
    return this.metric!=null?this.metric.build():null;
  }
  public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricIdentifier buildMetric() {
    return this.metric!=null?this.metric.build():null;
  }
  public A withMetric(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricIdentifier metric) {
    _visitables.get("metric").remove(this.metric);
    if (metric!=null){ this.metric= new io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricIdentifierBuilder(metric); _visitables.get("metric").add(this.metric);} return (A) this;
  }
  public java.lang.Boolean hasMetric() {
    return this.metric != null;
  }
  public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ExternalMetricSourceFluent.MetricNested<A> withNewMetric() {
    return new io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ExternalMetricSourceFluentImpl.MetricNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ExternalMetricSourceFluent.MetricNested<A> withNewMetricLike(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricIdentifier item) {
    return new io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ExternalMetricSourceFluentImpl.MetricNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ExternalMetricSourceFluent.MetricNested<A> editMetric() {
    return withNewMetricLike(getMetric());
  }
  public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ExternalMetricSourceFluent.MetricNested<A> editOrNewMetric() {
    return withNewMetricLike(getMetric() != null ? getMetric(): new io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricIdentifierBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ExternalMetricSourceFluent.MetricNested<A> editOrNewMetricLike(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricIdentifier item) {
    return withNewMetricLike(getMetric() != null ? getMetric(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildTarget instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricTarget getTarget() {
    return this.target!=null?this.target.build():null;
  }
  public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricTarget buildTarget() {
    return this.target!=null?this.target.build():null;
  }
  public A withTarget(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricTarget target) {
    _visitables.get("target").remove(this.target);
    if (target!=null){ this.target= new io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricTargetBuilder(target); _visitables.get("target").add(this.target);} return (A) this;
  }
  public java.lang.Boolean hasTarget() {
    return this.target != null;
  }
  public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ExternalMetricSourceFluent.TargetNested<A> withNewTarget() {
    return new io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ExternalMetricSourceFluentImpl.TargetNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ExternalMetricSourceFluent.TargetNested<A> withNewTargetLike(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricTarget item) {
    return new io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ExternalMetricSourceFluentImpl.TargetNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ExternalMetricSourceFluent.TargetNested<A> editTarget() {
    return withNewTargetLike(getTarget());
  }
  public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ExternalMetricSourceFluent.TargetNested<A> editOrNewTarget() {
    return withNewTargetLike(getTarget() != null ? getTarget(): new io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricTargetBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ExternalMetricSourceFluent.TargetNested<A> editOrNewTargetLike(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricTarget item) {
    return withNewTargetLike(getTarget() != null ? getTarget(): item);
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ExternalMetricSourceFluentImpl that = (ExternalMetricSourceFluentImpl) o;
    if (metric != null ? !metric.equals(that.metric) :that.metric != null) return false;
    if (target != null ? !target.equals(that.target) :that.target != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(metric,  target,  additionalProperties,  super.hashCode());
  }
  public class MetricNestedImpl<N> extends io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricIdentifierFluentImpl<io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ExternalMetricSourceFluent.MetricNested<N>> implements io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ExternalMetricSourceFluent.MetricNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    MetricNestedImpl(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricIdentifier item) {
      this.builder = new io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricIdentifierBuilder(this, item);
    }
    MetricNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricIdentifierBuilder(this);
    }
    io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricIdentifierBuilder builder;
    public N and() {
      return (N) ExternalMetricSourceFluentImpl.this.withMetric(builder.build());
    }
    public N endMetric() {
      return and();
    }
    
  }
  public class TargetNestedImpl<N> extends io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricTargetFluentImpl<io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ExternalMetricSourceFluent.TargetNested<N>> implements io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ExternalMetricSourceFluent.TargetNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    TargetNestedImpl(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricTarget item) {
      this.builder = new io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricTargetBuilder(this, item);
    }
    TargetNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricTargetBuilder(this);
    }
    io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricTargetBuilder builder;
    public N and() {
      return (N) ExternalMetricSourceFluentImpl.this.withTarget(builder.build());
    }
    public N endTarget() {
      return and();
    }
    
  }
  
}

==> kubernetes-model-autoscaling-5.12.4-sources.jar: io/fabric8/kubernetes/api/model/autoscaling/v2beta2/ExternalMetricSourceFluentImpl.java <==
package io.fabric8.kubernetes.api.model.autoscaling.v2beta2;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class ExternalMetricSourceFluentImpl<A extends io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ExternalMetricSourceFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ExternalMetricSourceFluent<A>{
  public ExternalMetricSourceFluentImpl() {
  }
  public ExternalMetricSourceFluentImpl(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ExternalMetricSource instance) {
    this.withMetric(instance.getMetric()); 
    this.withTarget(instance.getTarget()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricIdentifierBuilder metric;
  private io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricTargetBuilder target;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildMetric instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricIdentifier getMetric() {
    return this.metric!=null?this.metric.build():null;
  }
  public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricIdentifier buildMetric() {
    return this.metric!=null?this.metric.build():null;
  }
  public A withMetric(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricIdentifier metric) {
    _visitables.get("metric").remove(this.metric);
    if (metric!=null){ this.metric= new io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricIdentifierBuilder(metric); _visitables.get("metric").add(this.metric);} return (A) this;
  }
  public java.lang.Boolean hasMetric() {
    return this.metric != null;
  }
  public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ExternalMetricSourceFluent.MetricNested<A> withNewMetric() {
    return new io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ExternalMetricSourceFluentImpl.MetricNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ExternalMetricSourceFluent.MetricNested<A> withNewMetricLike(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricIdentifier item) {
    return new io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ExternalMetricSourceFluentImpl.MetricNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ExternalMetricSourceFluent.MetricNested<A> editMetric() {
    return withNewMetricLike(getMetric());
  }
  public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ExternalMetricSourceFluent.MetricNested<A> editOrNewMetric() {
    return withNewMetricLike(getMetric() != null ? getMetric(): new io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricIdentifierBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ExternalMetricSourceFluent.MetricNested<A> editOrNewMetricLike(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricIdentifier item) {
    return withNewMetricLike(getMetric() != null ? getMetric(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildTarget instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricTarget getTarget() {
    return this.target!=null?this.target.build():null;
  }
  public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricTarget buildTarget() {
    return this.target!=null?this.target.build():null;
  }
  public A withTarget(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricTarget target) {
    _visitables.get("target").remove(this.target);
    if (target!=null){ this.target= new io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricTargetBuilder(target); _visitables.get("target").add(this.target);} return (A) this;
  }
  public java.lang.Boolean hasTarget() {
    return this.target != null;
  }
  public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ExternalMetricSourceFluent.TargetNested<A> withNewTarget() {
    return new io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ExternalMetricSourceFluentImpl.TargetNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ExternalMetricSourceFluent.TargetNested<A> withNewTargetLike(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricTarget item) {
    return new io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ExternalMetricSourceFluentImpl.TargetNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ExternalMetricSourceFluent.TargetNested<A> editTarget() {
    return withNewTargetLike(getTarget());
  }
  public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ExternalMetricSourceFluent.TargetNested<A> editOrNewTarget() {
    return withNewTargetLike(getTarget() != null ? getTarget(): new io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricTargetBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ExternalMetricSourceFluent.TargetNested<A> editOrNewTargetLike(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricTarget item) {
    return withNewTargetLike(getTarget() != null ? getTarget(): item);
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ExternalMetricSourceFluentImpl that = (ExternalMetricSourceFluentImpl) o;
    if (metric != null ? !metric.equals(that.metric) :that.metric != null) return false;
    if (target != null ? !target.equals(that.target) :that.target != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(metric,  target,  additionalProperties,  super.hashCode());
  }
  public class MetricNestedImpl<N> extends io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricIdentifierFluentImpl<io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ExternalMetricSourceFluent.MetricNested<N>> implements io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ExternalMetricSourceFluent.MetricNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    MetricNestedImpl(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricIdentifier item) {
      this.builder = new io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricIdentifierBuilder(this, item);
    }
    MetricNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricIdentifierBuilder(this);
    }
    io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricIdentifierBuilder builder;
    public N and() {
      return (N) ExternalMetricSourceFluentImpl.this.withMetric(builder.build());
    }
    public N endMetric() {
      return and();
    }
    
  }
  public class TargetNestedImpl<N> extends io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricTargetFluentImpl<io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ExternalMetricSourceFluent.TargetNested<N>> implements io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ExternalMetricSourceFluent.TargetNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    TargetNestedImpl(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricTarget item) {
      this.builder = new io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricTargetBuilder(this, item);
    }
    TargetNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricTargetBuilder(this);
    }
    io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricTargetBuilder builder;
    public N and() {
      return (N) ExternalMetricSourceFluentImpl.this.withTarget(builder.build());
    }
    public N endTarget() {
      return and();
    }
    
  }
  
}
